@@ -27,7 +27,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Henryhaoson"
     author_url = "https://git.17bdc.com/android-apps/sentry-dingtalk"
-    version = "2.0.5"
+    version = "2.0.6"
     resource_links = [
         ("Report Issue", "https://git.17bdc.com/android-apps/sentry-dingtalk/issues"),
         ("View Source", "https://git.17bdc.com/android-apps/sentry-dingtalk"),
@@ -54,9 +54,20 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
                 "type": "url",
                 "placeholder": "https://oapi.dingtalk.com/robot/send?access_token=**********",
                 "required": True,
-                "help": "Your custom DingTalk webhook",
+                "help": "钉钉 webhook 会@ 成员",
                 "default": self.set_default(project, "webhook", "DINGTALK_WEBHOOK"),
             },
+            {
+                "name": "webhook_optional",
+                "label": "webhook_optional",
+                "type": "url",
+                "placeholder": "https://oapi.dingtalk.com/robot/send?access_token=**********",
+                "required": False,
+                "help": "Optional - 可选 webhook， 不会 @成员",
+                "default": self.set_default(
+                    project, "webhook_optional", ""
+                ),
+            },
             {
                 "name": "ats",
                 "label": "@成员",
@@ -88,6 +99,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
 
     def _post(self, group, userId, release, project):
         webhook = self.get_option("webhook", project)
+        webhook_optional = self.get_option("webhook_optional", project)
         ats_str = self.get_option("ats", project)
         ats_array = ats_str.split(",")
         ats_ding_str = ""
@@ -101,7 +113,6 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} #### Project: {project.name} \n\n"
         payload = f"{payload} #### release: {release} \n\n"
         payload = f"{payload} > Detail: {group.message} \n\n"
-        payload = f"{payload} {ats_ding_str} \n\n"
 
         headers = {
             "Content-type": "application/json",
@@ -120,5 +131,11 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
                 "isAtAll": "false"
             }
         }
+        # 可选 webhook，不会 @ 成员
+        if len(webhook_optional) != 0:
+            requests.post(webhook_optional, data=json.dumps(
+                data), headers=headers)
 
+        # 必填 webhook，如果配置了 @ 成员，会执行
+        payload = f"{payload} {ats_ding_str} \n\n"
         requests.post(webhook, data=json.dumps(data), headers=headers)
